==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebRowDataEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDetailDescription } from "./WebRowDataEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowDataEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowDataEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowDataEventArgsDetailDescriptionMetadata.a == null) {
                WebRowDataEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowDataEventArgsDetailDescriptionMetadata.c(WebRowDataEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowDataEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRowDataEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowDataEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Data", "Unknown");
            a.item("PrimaryKey", "Unknown");
        }
        static d(a) {
            WebRowDataEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebRowDataEventArgsDetail", () => new WebRowDataEventArgsDetailDescription());
            a.ac("WebRowDataEventArgsDetail", WebRowDataEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowDataEventArgsDetailDescriptionMetadata.$t = markType(WebRowDataEventArgsDetailDescriptionMetadata, 'WebRowDataEventArgsDetailDescriptionMetadata');
    WebRowDataEventArgsDetailDescriptionMetadata.a = null;
    return WebRowDataEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebRowDataEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowDataEventArgsDetailDescription } from "./WebRowDataEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowDataEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowDataEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowDataEventArgsDetailDescriptionMetadata.a == null) {
                WebRowDataEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowDataEventArgsDetailDescriptionMetadata.c(WebRowDataEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowDataEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRowDataEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowDataEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Data", "Unknown");
            a.item("RowData", "Unknown");
            a.item("PrimaryKey", "Unknown");
            a.item("RowKey", "Unknown");
        }
        static d(a) {
            WebRowDataEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebRowDataEventArgsDetail", () => new WebRowDataEventArgsDetailDescription());
            a.ad("WebRowDataEventArgsDetail", WebRowDataEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowDataEventArgsDetailDescriptionMetadata.$t = markType(WebRowDataEventArgsDetailDescriptionMetadata, 'WebRowDataEventArgsDetailDescriptionMetadata');
    WebRowDataEventArgsDetailDescriptionMetadata.a = null;
    return WebRowDataEventArgsDetailDescriptionMetadata;
})();
